bayespy.inference.vmp.nodes.gaussian.GaussianGammaARDToGaussianWishart.get_shape
================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaARDToGaussianWishart.get_shape